@@ -1,6 +1,7 @@
 import RPi.GPIO as GPIO
 import spidev
 import logging
+import time
 
 
 class MFRC522:
@@ -144,7 +145,7 @@ class MFRC522:
             else:
                 pin_rst = 22
 
-        self.StopAuth = self.StopCrypto1()
+        self.StopAuth = self.StopCrypto1
         # Set up reset pin and initialize MFRC522 RFID reader
         GPIO.setup(pin_rst, GPIO.OUT)
         GPIO.output(pin_rst, 1)
@@ -305,6 +306,7 @@ class MFRC522:
         # Wait for command execution (timeout)
         i = 2000
         while True:
+            time.sleep(0.35)
             n = self.ReadReg(self.CommIrqReg)
             i -= 1
             # Break if interrupt request received or timeout
